<?php

class MKKPublic
{
    public function __construct()
    {
        $this->_setHooks();
    }

    private function _setHooks()
    {
        if (!is_admin()) {
            $this->_configureTemplates();
            $this->_addStyles();
            $this->_addScripts();

            add_filter('mblp_allow_shop_page', '__return_true');

            add_action('mbl_after_search_hint_form', [$this, 'addShopMenu']);

            add_filter('mbl_home_id', [$this, 'customHomeId']);
            add_filter('mbl_home_title', [$this, 'mblHomeTitle']);
            add_filter('mbl_home_name', [$this, 'mblHomeTitle']);
            add_filter('mbl_home_icon_class', [$this, 'mblHomeIconClass']);

            //Показать страницы уровней доступа
            add_filter('mbl_template_include', [$this, 'mkk_get_template'], 101);
            add_filter('mkk_product_render_add_to_cart_btn', [$this, 'renderAddToCartButton'], 10, 2);
            add_filter('body_class', [$this, 'bodyClass']);
        }

        add_filter('mbl_get_main_page', [$this, 'customHomeId']);
        add_filter('mbl_home_id_field_name', [$this, 'mblHomeIdFieldNameFilter']);
        add_filter('mbl_redirect_is_single', [$this, 'mblRedirectIsSingleFilter']);

        /**
         * Favorites and My Courses page
         */
        add_rewrite_rule('^favorites/?$', 'index.php?post_type=product&favorites=true', 'top');
        add_rewrite_rule('^favorites/page/([0-9]+)/?$', 'index.php?post_type=product&favorites=true&paged=$matches[1]', 'top');
        add_rewrite_rule('^my-courses/?$', 'index.php?post_type=product&my_courses=true', 'top');
        add_rewrite_rule('^my-courses/page/([0-9]+)/?$', 'index.php?post_type=product&my_courses=true&paged=$matches[1]', 'top');
        add_filter('query_vars', [$this, 'customQueryVars']);
        add_filter('posts_where', [$this, 'postWhere'], 10, 2);
        add_action( 'template_redirect', [$this, 'templateRedirect'] );
        add_action( 'pre_get_posts', [$this, 'getProductFeatured'] );
    }

    private function _configureTemplates()
    {
        add_filter('mbl_template_include', [$this, 'addMBLTemplate'], 1001);
    }

    public function addMBLTemplate($template)
    {
        $main_options = get_option('wpm_main_options');

        if (mkk_is_favorite_page()) {
            $template = $this->_getTemplatePath('courses');
        } elseif (mkk_is_my_courses_page()) {
            $template = $this->_getTemplatePath('courses');
        } elseif (is_shop() || is_product_category()) {

            $template = $this->_getTemplatePath('shop');

            if (!is_user_logged_in() && !$main_options['main']['opened']) {
                $template = _wpm_get_template_path('category');
            }

        }

        return $template;
    }

    private function _getTemplatePath($template)
    {
        $path = "templates/public/layouts/{$template}.php";

        return MKK_DIR . $path;
    }

    private function _addStyles()
    {
        add_action("wpm_head", [$this, 'addStyles'], 902);
    }

    public function addStyles()
    {
        wpm_enqueue_style('mkk_main', plugins_url('/mbl-catalog/assets/css/main.css?v=' . MKK_VERSION));
        mkk_render_partial('partials/css');
    }


    private function _addScripts()
    {
        add_action("wpm_footer", [$this, 'addScripts'], 902);
    }

    public function customHomeId($home_id)
    {
        return wpm_get_option('mkk.set_as_mainpage_keep_link') == 'on'
            ? wpm_get_option('mkk.old_mainpage')
            : $home_id;
    }

    public function mblHomeTitle($title)
    {
        return wpm_get_option('mkk.set_as_mainpage_keep_link') == 'on'
            ? wpm_get_option('mkk_texts.menu_name')
            : $title;
    }

    public function mblHomeIconClass($iconClass)
    {
        return wpm_get_option('mkk.set_as_mainpage_keep_link') == 'on'
            ? 'iconmoon icon-star'
            : $iconClass;
    }

    public function mblHomeIdFieldNameFilter($fieldName)
    {
        return wpm_get_option('mkk.set_as_mainpage_keep_link') == 'on'
            ? 'main_options[mkk][old_mainpage]'
            : $fieldName;
    }

    public function mblRedirectIsSingleFilter($is_single)
    {
        return $is_single || is_shop();
    }

    public function renderAddToCartButton($product, $href)
    {
        $free = empty($product->get_price());

        return mkk_render_partial('partials/add-to-cart-btn', 'public', compact('href', 'free'));
    }

    public function addScripts()
    {
        wpm_enqueue_script('mkk_js_main', plugins_url('/mbl-catalog/assets/js/mkk_public.js?v=' . MKK_VERSION));
    }

    public function addShopMenu()
    {
        mkk_render_partial('partials/shop-menu');
    }

    function mkk_get_template($template)
    {
        if (is_tax('wpm-levels')) {
            return MKK_DIR . "templates/public/layouts/wpm-levels.php";
        } else {
            return $template;
        }
    }

    function customQueryVars($query_vars) {
        $query_vars[] = 'favorites';
        $query_vars[] = 'my_courses';

        return $query_vars;
    }

    public function templateRedirect() {
        global $wp_query;
        if ((isset($wp_query->query_vars['favorites']) || isset($wp_query->query_vars['my_courses']))
            && !is_user_logged_in()) {
            wp_redirect( home_url() );
            exit();
        }
    }

    public function postWhere(string $where, WP_Query $query): string
    {
        global $wpdb;
        if ($query->is_main_query() && is_user_logged_in()) {
            $user_id = get_current_user_id();
            if (isset($query->query_vars['favorites'])) {
                $tb = "{$wpdb->prefix}memberlux_favorites";
                $where .= " AND $wpdb->posts.ID IN(SELECT product_id FROM $tb WHERE user_id = $user_id)";
            } elseif (isset($query->query_vars['my_courses'])) {
                $where .= " AND $wpdb->posts.ID IN(
                    SELECT DISTINCT available.post_id
                    FROM $wpdb->postmeta AS available
                    LEFT JOIN {$wpdb->prefix}memberlux_term_keys AS tk
                        ON tk.user_id = $user_id AND available.meta_value = tk.term_id
                    WHERE available.meta_key = '_mbl_key_pin_code_level_id' 
                    AND ((tk.is_unlimited != 1 AND tk.date_end >= NOW()) OR tk.is_unlimited = 1)
                    AND tk.is_banned != 1 AND tk.key_type = 'wpm_term_keys'
                )";
            }
        }
        /*
        SELECT DISTINCT available.post_id
        FROM wp_postmeta AS available
        LEFT JOIN wp_memberlux_term_keys AS tk
            ON tk.user_id = 8 AND available.meta_value = tk.term_id
        WHERE available.meta_key = '_mbl_key_pin_code_level_id' AND ((tk.is_unlimited != 1 AND tk.date_end >= NOW()) OR tk.is_unlimited = 1)
        AND tk.is_banned != 1 AND tk.key_type = 'wpm_term_keys'
         */

        return $where;
    }

    public function getProductFeatured(WP_Query $query) {
        if (
            $query->is_main_query()
            && (isset($query->query_vars['favorites']) || isset($query->query_vars['my_courses']))
        ) {
            if (!empty($query->query_vars['tax_query'])) {
                $tax_query = $query->query_vars['tax_query'];
            } else {
                $tax_query = [];
            }
            $featured = [
                [
                    'taxonomy' => 'product_visibility',
                    'field' => 'name',
                    'terms' => 'featured',
                ]
            ];
            $query->set('tax_query', array_merge($tax_query, $featured));
        }
        if ( !is_admin() && $query->is_main_query() && (is_post_type_archive( 'product' ) || is_product_category()) ) {
            $query->set( 'posts_per_page', intval(wpm_get_option('main.product_per_page', -1)) );
        }
    }

    public function bodyClass($classes) {
        if (mkk_is_favorite_page()) {
            $classes[] = 'mkk-favorite-page';
        } elseif (mkk_is_my_courses_page()) {
            $classes[] = 'mkk-my-courses-page';
        }

        return $classes;
    }
}
