<?php

class MKKRest
{
    private string $namespace = 'mkk/v1';

    public function init()
    {
        add_action('rest_api_init', [$this, 'registerRestRoutes']);
    }

    public function url(): string
    {
        return rest_url($this->namespace);
    }

    public function registerRestRoutes()
    {
        register_rest_route($this->namespace, '/favorites/add/(?P<product_id>\d+)', array(
            'methods' => 'POST',
            'callback' => [$this, 'addFavorites'],
            'permission_callback' => fn() => is_user_logged_in(),
            'args' => [
                'product_id' => [
                    'required' => true,
                    'type' => 'integer'
                ]
            ]
        ));
        register_rest_route($this->namespace, '/favorites/remove/(?P<product_id>\d+)', array(
            'methods' => 'POST',
            'callback' => [$this, 'removeFavorites'],
            'permission_callback' => fn() => is_user_logged_in(),
            'args' => [
                'product_id' => [
                    'required' => true,
                    'type' => 'integer'
                ]
            ]
        ));
    }

    public function addFavorites(WP_REST_Request $request): array
    {
        global $wpdb;
        $product_id = absint($request->get_param('product_id'));
        $user_id = get_current_user_id();
        $tb = "{$wpdb->prefix}memberlux_favorites";
        $exist = $wpdb->get_var("SELECT product_id FROM $tb WHERE user_id = $user_id AND product_id = $product_id");
        if (empty($exist)) {
            $wpdb->insert($tb, ['product_id' => $product_id, 'user_id' => $user_id]);
        }

        return ['ok' => true];
    }

    public function removeFavorites(WP_REST_Request $request): array
    {
        global $wpdb;
        $product_id = absint($request->get_param('product_id'));
        $user_id = get_current_user_id();
        $tb = "{$wpdb->prefix}memberlux_favorites";
        $exist = $wpdb->get_var("SELECT product_id FROM $tb WHERE user_id = $user_id AND product_id = $product_id");
        if (!empty($exist)) {
            $wpdb->delete($tb, ['product_id' => $product_id, 'user_id' => $user_id]);
        }

        return ['ok' => true];
    }
}
